import datetime,random,time

from common_pims.lib.public import *

class Context:
    # pass
    time_1 = time_1()
    random_n = random_n()
    random_num = random_num()
    time_2 = time_2()
    random_nu = random_nu()
    random_nu1 = random_nu1()
    random_three=random_three()
    random_z =random_z()
    pems_random = pems_random()
    time_st = time_st()
    time_ots=time_ots()
    time_r = time_r()
    random_six =random_six()
    random_cms = random_cms()
    random_cmsgwmc =random_cmsgwmc()
    random_cmszj = random_cmszj()
    random_cmsgwjb = random_cmsgwjb()
    random_cmsdeptno = random_cmsdeptno()
    time_cms =time_cms()
    time_ny=time_ny()
    time_nyyc=time_nyyc()
    time_nyrsfmyc=time_nyrsfmyc()
    time_nyc=time_nyc()
    random_cmsxgbrma =random_cmsxgbrma()
    random_cmsxgbrmb =random_cmsxgbrmb()
    random_cmsxgbrmc =random_cmsxgbrmc()
    random_cmsxgbrmd =random_cmsxgbrmd()
    get_time_one=get_time_one()
    get_shijian_ten = get_shijian_ten()
    time_xny=time_xny()
    id_card = id_card()
    get_next_month_otherday=get_next_month_otherday()
    time_month=time_month()
    get_next_month=get_next_month()
    get_next2_month=get_next2_month()
    time_3=time_3()



